======================================
Release notes and upgrade instructions
======================================

.. releasestree::
    :maxdepth: 1
    :glob:

    *

.. seealso:: :doc:`Legacy salt-cloud release docs <../cloud/releases/index>`
